@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminPackageManager.pm - manage software packages
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: AdminPackageManager.pm,v 1.108.2.1 2012-12-17 13:04:06 mn Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -20,9 +18,6 @@ use Kernel::System::Package;
 use Kernel::System::Web::UploadCache;
 use Kernel::System::Cache;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.108.2.1 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -55,12 +50,12 @@ sub Run {
     # ------------------------------------------------------------ #
 
     if ( exists $ENV{MOD_PERL} ) {
-        if ( defined $mod_perl::VERSION ) {
-            if ( $mod_perl::VERSION >= 1.99 ) {
+        if ( defined $mod_perl::VERSION ) {    ## no critic
+            if ( $mod_perl::VERSION >= 1.99 ) {    ## no critic
 
                 # check if Apache::Reload is loaded
                 my $ApacheReload = 0;
-                for my $Module ( keys %INC ) {
+                for my $Module ( sort keys %INC ) {
                     $Module =~ s/\//::/g;
                     $Module =~ s/\.pm$//g;
                     if ( $Module eq 'Apache::Reload' || $Module eq 'Apache2::Reload' ) {
@@ -221,7 +216,11 @@ sub Run {
         my %DeployInfo = $Self->{PackageObject}->DeployCheckInfo();
         $Self->{LayoutObject}->Block(
             Name => 'Package',
-            Data => { %Param, %Frontend, Name => $Name, Version => $Version, },
+            Data => {
+                %Param, %Frontend,
+                Name    => $Name,
+                Version => $Version,
+            },
         );
         for my $PackageAction (qw(DownloadLocal Rebuild Reinstall)) {
             $Self->{LayoutObject}->Block(
@@ -255,7 +254,10 @@ sub Run {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
                 elsif ( $Key =~ /^Database(Install|Reinstall|Upgrade|Uninstall)$/ ) {
@@ -265,14 +267,21 @@ sub Run {
                                 if ( $Hash->{Tag} =~ /^Table/ ) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabase",
-                                        Data => { %{$Hash}, TagName => $Key, Type => $Type },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                            Type    => $Type
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
-                                        Data => { %{$Hash}, TagName => $Key, },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
@@ -287,7 +296,10 @@ sub Run {
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
-                                        Data => { TagName => $Key, SQL => $SQL, },
+                                        Data => {
+                                            TagName => $Key,
+                                            SQL     => $SQL,
+                                        },
                                     );
                                 }
                                 @DatabaseBuffer = ();
@@ -298,7 +310,10 @@ sub Run {
                 else {
                     $Self->{LayoutObject}->Block(
                         Name => 'PackageItemGeneric',
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
             }
@@ -307,7 +322,10 @@ sub Run {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItem$Key",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Key =~ /^Code/ ) {
@@ -318,17 +336,22 @@ sub Run {
                         );
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemCode",
-                            Data => { Tag => $Key, %{$Hash} },
+                            Data => {
+                                Tag => $Key,
+                                %{$Hash}
+                            },
                         );
                     }
                     elsif ( $Key =~ /^(Intro)/ ) {
                         if ( $Hash->{Format} && $Hash->{Format} =~ /plain/i ) {
-                            $Hash->{Content}
-                                = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
+                            $Hash->{Content} = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
                         }
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemIntro",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Hash->{Tag} =~ /^(File)$/ ) {
@@ -398,7 +421,10 @@ sub Run {
                     else {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemGeneric",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                 }
@@ -457,7 +483,10 @@ sub Run {
         );
         $Self->{LayoutObject}->Block(
             Name => 'PackageDownloadRemote',
-            Data => { %Param, %Frontend, File => $File, },
+            Data => {
+                %Param, %Frontend,
+                File => $File,
+            },
         );
 
         # check if file is requested
@@ -480,7 +509,10 @@ sub Run {
                 if ( $Key =~ /^(Description|Filelist)$/ ) {
                     $Self->{LayoutObject}->Block(
                         Name => "PackageItem$Key",
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
                 elsif ( $Key =~ /^Database(Install|Reinstall|Upgrade|Uninstall)$/ ) {
@@ -490,14 +522,21 @@ sub Run {
                                 if ( $Hash->{Tag} =~ /^Table/ ) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabase",
-                                        Data => { %{$Hash}, TagName => $Key, Type => $Type },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                            Type    => $Type
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
                                 else {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSub",
-                                        Data => { %{$Hash}, TagName => $Key, },
+                                        Data => {
+                                            %{$Hash},
+                                            TagName => $Key,
+                                        },
                                     );
                                     push @DatabaseBuffer, $Hash;
                                 }
@@ -512,7 +551,10 @@ sub Run {
                                 for my $SQL (@SQL) {
                                     $Self->{LayoutObject}->Block(
                                         Name => "PackageItemDatabaseSQL",
-                                        Data => { TagName => $Key, SQL => $SQL, },
+                                        Data => {
+                                            TagName => $Key,
+                                            SQL     => $SQL,
+                                        },
                                     );
                                 }
                                 @DatabaseBuffer = ();
@@ -523,7 +565,10 @@ sub Run {
                 else {
                     $Self->{LayoutObject}->Block(
                         Name => 'PackageItemGeneric',
-                        Data => { Tag => $Key, %{ $Structure{$Key} } },
+                        Data => {
+                            Tag => $Key,
+                            %{ $Structure{$Key} }
+                        },
                     );
                 }
             }
@@ -532,7 +577,10 @@ sub Run {
                     if ( $Key =~ /^(Description|ChangeLog)$/ ) {
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItem$Key",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Key =~ /^Code/ ) {
@@ -543,17 +591,22 @@ sub Run {
                         );
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemCode",
-                            Data => { Tag => $Key, %{$Hash} },
+                            Data => {
+                                Tag => $Key,
+                                %{$Hash}
+                            },
                         );
                     }
                     elsif ( $Key =~ /^(Intro)/ ) {
                         if ( $Hash->{Format} && $Hash->{Format} =~ /plain/i ) {
-                            $Hash->{Content}
-                                = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
+                            $Hash->{Content} = '<pre class="contentbody">' . $Hash->{Content} . '</pre>';
                         }
                         $Self->{LayoutObject}->Block(
                             Name => "PackageItemIntro",
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                     elsif ( $Hash->{Tag} =~ /^(File)$/ ) {
@@ -586,7 +639,10 @@ sub Run {
                     else {
                         $Self->{LayoutObject}->Block(
                             Name => 'PackageItemGeneric',
-                            Data => { %{$Hash}, Tag => $Key, },
+                            Data => {
+                                %{$Hash},
+                                Tag => $Key,
+                            },
                         );
                     }
                 }
@@ -756,12 +812,17 @@ sub Run {
         }
 
         # check if we have to show reinstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         my %Data;
         if ( $Structure{IntroReinstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroReinstall}, Type => 'pre' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroReinstall},
+                Type => 'pre'
+            );
         }
         if ( %Data && !$IntroReinstallPre ) {
             $Self->{LayoutObject}->Block(
@@ -831,7 +892,9 @@ sub Run {
         }
 
         # check if we have to show reinstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         if ( !$Self->{PackageObject}->PackageReinstall( String => $Package ) ) {
@@ -839,7 +902,10 @@ sub Run {
         }
         my %Data;
         if ( $Structure{IntroReinstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroReinstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroReinstall},
+                Type => 'post'
+            );
         }
         if ( %Data && !$IntroReinstallPost ) {
             $Self->{LayoutObject}->Block(
@@ -890,12 +956,17 @@ sub Run {
         }
 
         # check if we have to show uninstall intro pre
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # intro screen
         my %Data;
         if ( $Structure{IntroUninstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUninstall}, Type => 'pre' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUninstall},
+                Type => 'pre'
+            );
         }
         if ( %Data && !$IntroUninstallPre ) {
             $Self->{LayoutObject}->Block(
@@ -964,7 +1035,9 @@ sub Run {
         }
 
         # parse package
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
 
         # unsinstall the package
         if ( !$Self->{PackageObject}->PackageUninstall( String => $Package ) ) {
@@ -974,7 +1047,10 @@ sub Run {
         # intro screen
         my %Data;
         if ( $Structure{IntroUninstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUninstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUninstall},
+                Type => 'post'
+            );
         }
         if ( %Data && !$IntroUninstallPost ) {
             my %Data = $Self->_MessageGet( Info => $Structure{IntroUninstallPost} );
@@ -1043,8 +1119,7 @@ sub Run {
             }
         }
         if ( !%Errors ) {
-            my $Feedback
-                = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
+            my $Feedback = $Self->{PackageObject}->PackageIsInstalled( String => $UploadStuff{Content} );
 
             if ($Feedback) {
                 return $Self->_UpgradeHandling(
@@ -1079,7 +1154,9 @@ sub Run {
         if ( !$Package ) {
             return $Self->{LayoutObject}->ErrorScreen( Message => 'No such package!' );
         }
-        my %Structure = $Self->{PackageObject}->PackageParse( String => $Package, );
+        my %Structure = $Self->{PackageObject}->PackageParse(
+            String => $Package,
+        );
         my $File = $Self->{PackageObject}->PackageBuild(%Structure);
         return $Self->{LayoutObject}->Attachment(
             Content     => $File,
@@ -1104,9 +1181,9 @@ sub Run {
         %RepositoryRoot = $Self->{PackageObject}->PackageOnlineRepositories();
     }
     $Frontend{SourceList} = $Self->{LayoutObject}->BuildSelection(
-        Data => { %List, %RepositoryRoot, },
-        Name => 'Source',
-        Max  => 40,
+        Data        => { %List, %RepositoryRoot, },
+        Name        => 'Source',
+        Max         => 40,
         Translation => 0,
         SelectedID  => $Source,
         Class       => "W100pc",
@@ -1121,7 +1198,9 @@ sub Run {
             Lang => $Self->{LayoutObject}->{UserLanguage},
         );
         if ( !@List ) {
-            $OutputNotify .= $Self->{LayoutObject}->Notify( Priority => 'Error', );
+            $OutputNotify .= $Self->{LayoutObject}->Notify(
+                Priority => 'Error',
+            );
             if ( !$OutputNotify ) {
                 $OutputNotify .= $Self->{LayoutObject}->Notify(
                     Priority => 'Info',
@@ -1161,13 +1240,19 @@ sub Run {
             if ( $Data->{Upgrade} ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ShowRemotePackageUpgrade',
-                    Data => { %{$Data}, Source => $Source, },
+                    Data => {
+                        %{$Data},
+                        Source => $Source,
+                    },
                 );
             }
             elsif ( !$Data->{Installed} ) {
                 $Self->{LayoutObject}->Block(
                     Name => 'ShowRemotePackageInstall',
-                    Data => { %{$Data}, Source => $Source, },
+                    Data => {
+                        %{$Data},
+                        Source => $Source,
+                    },
                 );
             }
         }
@@ -1531,7 +1616,10 @@ sub _InstallHandling {
     # intro screen
     my %Data;
     if ( $Structure{IntroInstall} ) {
-        %Data = $Self->_MessageGet( Info => $Structure{IntroInstall}, Type => 'pre' );
+        %Data = $Self->_MessageGet(
+            Info => $Structure{IntroInstall},
+            Type => 'pre'
+        );
     }
 
     # intro before installation
@@ -1573,7 +1661,10 @@ sub _InstallHandling {
         # intro screen
         my %Data;
         if ( $Structure{IntroInstall} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroInstall}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroInstall},
+                Type => 'post'
+            );
         }
         if (%Data) {
             $Self->{LayoutObject}->Block(
@@ -1626,12 +1717,17 @@ sub _UpgradeHandling {
     my $IntroUpgradePre = $Self->{ParamObject}->GetParam( Param => 'IntroUpgradePre' ) || '';
 
     # check if we have to show upgrade intro pre
-    my %Structure = $Self->{PackageObject}->PackageParse( String => $Param{Package}, );
+    my %Structure = $Self->{PackageObject}->PackageParse(
+        String => $Param{Package},
+    );
 
     # intro screen
     my %Data;
     if ( $Structure{IntroUpgrade} ) {
-        %Data = $Self->_MessageGet( Info => $Structure{IntroUpgrade}, Type => 'pre' );
+        %Data = $Self->_MessageGet(
+            Info => $Structure{IntroUpgrade},
+            Type => 'pre'
+        );
     }
     if ( %Data && !$IntroUpgradePre ) {
         $Self->{LayoutObject}->Block(
@@ -1663,7 +1759,10 @@ sub _UpgradeHandling {
         # intro screen
         my %Data;
         if ( $Structure{IntroUpgrade} ) {
-            %Data = $Self->_MessageGet( Info => $Structure{IntroUpgrade}, Type => 'post' );
+            %Data = $Self->_MessageGet(
+                Info => $Structure{IntroUpgrade},
+                Type => 'post'
+            );
         }
         if (%Data) {
             $Self->{LayoutObject}->Block(
@@ -1697,17 +1796,17 @@ sub _GetFeatureAddonData {
     my ( $Self, %Param ) = @_;
 
     # Default URL
-    my $FeedURL = 'http://www.otrs.com/en/?type=104';
+    my $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=en';
 
     my $Language = $Self->{LayoutObject}->{UserLanguage};
 
     # Check if URL for UserLanguage is available
     if ( $Language =~ m/^de/ ) {
-        $FeedURL = 'http://www.otrs.com/de/?type=104';
+        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=de';
     }
 
     if ( $Language =~ m/^es/ ) {
-        $FeedURL = 'http://www.otrs.com/es/?type=104';
+        $FeedURL = 'http://www.otrs.com/feed/?post_type=feature_add_ons&lang=es';
     }
 
     my $CacheKey  = "FeatureAddonData::$FeedURL";
@@ -1746,23 +1845,10 @@ sub _GetFeatureAddonData {
         $Count++;
         last ITEM if $Count > 100;
 
-        #        my $Time = $Item->pubDate();
-        #        my $Ago;
-        #        if ($Time) {
-        #            my $SystemTime = $Self->{TimeObject}->TimeStamp2SystemTime(
-        #                String => $Time,
-        #            );
-        #            $Ago = $Self->{TimeObject}->SystemTime() - $SystemTime;
-        #            $Ago = $Self->{LayoutObject}->CustomerAge(
-        #                Age   => $Ago,
-        #                Space => ' ',
-        #            );
-        #        }
-
         push @Result, {
             Title       => $Item->title(),
             Link        => $Item->link(),
-            Description => $Item->description(),
+            Description => $Item->get('content:encoded'),
         };
     }
 
