@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminUser.pm - to add/update/delete user and preferences
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminUser.pm,v 1.80.2.1 2011-09-12 08:36:29 mg Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Kernel::System::Valid;
 use Kernel::System::CheckItem;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.80.2.1 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -54,6 +49,10 @@ sub Run {
         && $Self->{ConfigObject}->Get('SwitchToUser')
         )
     {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $UserID = $Self->{ParamObject}->GetParam( Param => 'UserID' ) || '';
         my %UserData = $Self->{UserObject}->GetUserData(
             UserID        => $UserID,
@@ -66,7 +65,7 @@ sub Run {
             Type   => 'rw',
             UserID => $UserData{UserID},
         );
-        for my $GroupKey ( keys %GroupData ) {
+        for my $GroupKey ( sort keys %GroupData ) {
             $UserData{"UserIsGroup[$GroupData{$GroupKey}]"} = 'Yes';
         }
 
@@ -76,12 +75,10 @@ sub Run {
             Type   => 'ro',
             UserID => $UserData{UserID},
         );
-        for my $GroupKey ( keys %GroupData ) {
+        for my $GroupKey ( sort keys %GroupData ) {
             $UserData{"UserIsGroupRo[$GroupData{$GroupKey}]"} = 'Yes';
         }
         my $NewSessionID = $Self->{SessionObject}->CreateSessionID(
-            _UserLogin => $UserData{UserLogin},
-            _UserPw    => 'lal',
             %UserData,
             UserLastRequest => $Self->{TimeObject}->SystemTime(),
             UserType        => 'User',
@@ -119,8 +116,7 @@ sub Run {
     # change
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Change' ) {
-        my $UserID
-            = $Self->{ParamObject}->GetParam( Param => 'UserID' )
+        my $UserID = $Self->{ParamObject}->GetParam( Param => 'UserID' )
             || $Self->{ParamObject}->GetParam( Param => 'ID' )
             || '';
         my %UserData = $Self->{UserObject}->GetUserData(
@@ -146,6 +142,10 @@ sub Run {
     # change action
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Note = '';
         my ( %GetParam, %Errors );
         for my $Parameter (
@@ -184,7 +184,7 @@ sub Run {
 
             if ($Update) {
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
-                for my $Group ( keys %Preferences ) {
+                for my $Group ( sort keys %Preferences ) {
                     next if $Group eq 'Password';
 
                     # get user data
@@ -202,18 +202,22 @@ sub Run {
                         ConfigItem => $Preferences{$Group},
                         Debug      => $Self->{Debug},
                     );
-                    my @Params
-                        = $Object->Param( %{ $Preferences{$Group} }, UserData => \%UserData );
+                    my @Params = $Object->Param( %{ $Preferences{$Group} }, UserData => \%UserData );
                     if (@Params) {
                         my %GetParam;
                         for my $ParamItem (@Params) {
-                            my @Array
-                                = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
+                            my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
                             if (@Array) {
                                 $GetParam{ $ParamItem->{Name} } = \@Array;
                             }
                         }
-                        if ( !$Object->Run( GetParam => \%GetParam, UserData => \%UserData ) ) {
+                        if (
+                            !$Object->Run(
+                                GetParam => \%GetParam,
+                                UserData => \%UserData
+                            )
+                            )
+                        {
                             $Note .= $Self->{LayoutObject}->Notify( Info => $Object->Error() );
                         }
                     }
@@ -290,6 +294,10 @@ sub Run {
     # add action
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
+
+        # challenge token check for write action
+        $Self->{LayoutObject}->ChallengeTokenCheck();
+
         my $Note = '';
         my ( %GetParam, %Errors );
         for my $Parameter (
@@ -330,7 +338,7 @@ sub Run {
 
                 # update preferences
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
-                for my $Group ( keys %Preferences ) {
+                for my $Group ( sort keys %Preferences ) {
                     next if $Group eq 'Password';
 
                     # get user data
@@ -352,12 +360,17 @@ sub Run {
                             PARAMITEM:
                             for my $ParamItem (@Params) {
                                 next PARAMITEM if !$ParamItem->{Name};
-                                my @Array
-                                    = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
+                                my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
 
                                 $GetParam{ $ParamItem->{Name} } = \@Array;
                             }
-                            if ( !$Object->Run( GetParam => \%GetParam, UserData => \%UserData ) ) {
+                            if (
+                                !$Object->Run(
+                                    GetParam => \%GetParam,
+                                    UserData => \%UserData
+                                )
+                                )
+                            {
                                 $Note .= $Self->{LayoutObject}->Notify( Info => $Object->Error() );
                             }
                         }
@@ -383,7 +396,9 @@ sub Run {
                     );
                 }
                 else {
-                    return $Self->{LayoutObject}->Redirect( OP => 'Action=AdminUser', );
+                    return $Self->{LayoutObject}->Redirect(
+                        OP => 'Action=AdminUser',
+                    );
                 }
             }
             else {
@@ -491,7 +506,7 @@ sub _Edit {
         my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
 
         GROUP:
-        for my $Group ( keys %Preferences ) {
+        for my $Group ( sort keys %Preferences ) {
             next GROUP if $Preferences{$Group}->{Column} ne $Column;
 
             if ( $Data{ $Preferences{$Group}->{Prio} } ) {
@@ -507,7 +522,7 @@ sub _Edit {
         }
 
         # sort
-        for my $Key ( keys %Data ) {
+        for my $Key ( sort keys %Data ) {
             $Data{ sprintf( "%07d", $Key ) } = $Data{$Key};
             delete $Data{$Key};
         }
@@ -539,7 +554,7 @@ sub _Edit {
                             Data => { %Param, },
                         );
                         if (
-                            ref( $ParamItem->{Data} )   eq 'HASH'
+                            ref( $ParamItem->{Data} ) eq 'HASH'
                             || ref( $Preference{Data} ) eq 'HASH'
                             )
                         {
