@@ -1,6 +1,6 @@
 # --
 # Helper.pm - unit test helper functions
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -8,6 +8,7 @@
 # --
 
 package Kernel::System::UnitTest::Helper;
+## nofilter(TidyAll::Plugin::OTRS::Perl::Time)
 
 use strict;
 use warnings;
@@ -132,7 +133,7 @@ creates a random ID that can be used in tests as a unique identifier.
 sub GetRandomID {
     my ( $Self, %Param ) = @_;
 
-    return 'test' . int( rand(1000000) )
+    return 'test-' . int( rand(1000000) )
 }
 
 =item TestUserCreate()
